@@ -5,6 +5,35 @@ import click
 #ctypes.windll.user32.MessageBoxW(0, msg, title, 1)
 
 
+class Logger(object):
+    def __init__(self, level):
+        self.level = level
+    
+    def info(self, msg):
+        self.log('info', msg)
+    
+    def debug(self, msg):
+        self.log("debug", msg)
+    
+    def warn(self, msg):
+        self.log("warn", msg)
+    
+    def error(self, msg):
+        self.info("error", msg)
+    
+    def log(self, level, msg):
+        level_list = ["debug", "info", "warn", "error"]
+        def get_level(l):
+            l = l.lower()
+            if l not in level_list:
+                return 0
+            return level_list.index(l)
+        log_level= get_level(level)
+        conf_level = get_level(self.level)
+        if log_level >= conf_level:
+            click.echo(msg)
+
+
 @click.group()
 def cli():
     pass
@@ -43,15 +72,19 @@ def parse_time(v):
 @click.option("--dir", multiple=True)
 @click.option("--sleep", default="300s")
 @click.option("--delete", default=1)
-def client(url, dir, sleep, delete):
-    click.echo("url:{}, dir:{}, sleep:{}, delete:{}".format(url,dir, sleep, delete))
+@click.option("--level",default="info")
+def client(url, dir, sleep, delete, level):
+    click.echo("url:{}, dir:{}, sleep:{}, delete:{}, level:{}".format(url,dir, sleep, delete, level))
     sleep = parse_time(sleep)
+
+    logger= Logger(level)
     
     from cqh_file import __version__
-    click.echo("version:{}".format(__version__))
+    logger.info("version:{}".format(__version__))
     from cqh_file.client import ClientLoop
     loop = ClientLoop(url=url, dir=dir, sleep=sleep, 
-    delete=delete)
+    delete=delete,
+    logger=logger)
     loop.loop()
 
 cli.add_command(serve)
